==> blue2-theme-simon-howie-dev-theme-1.1.8-0ba580.tar: templates/sections/flex-banner-slider.php <==
<?php

$title = get_sub_field("title") ?? "";

?>
<div class="section section--banner-slider">
    <div class="container">
        <?= $title !== "" ? "<h2 class='accent'>".$title."</h2>" : "" ; ?> 
        <div class="row">
        <?php
        if (have_rows('slides')) {
            ?>
            <div class="swiper-pagination"></div>
            <div class="swiper-container banner-slider-swiper">
                <div class="swiper-wrapper" style="height: 430px;">   
                    <?php
                    while (have_rows('slides')) { 
                        the_row();

                        $type = get_sub_field("type") ?? "";
                    
                        if ($type == "side") {

                            $side = get_sub_field("side") ?? "";
                            $sideTitle = get_sub_field("side_title") ?? "";
                            $sideText = get_sub_field("side_text") ?? "";
                            $sidePrimaryImage = get_sub_field("side_primary_image") ?? "";
                            $sideSecondaryImage = get_sub_field("side_secondary_image") ?? "";
                            $sideLink = get_sub_field("side_link") ?? "";
                            $sideLinkText = get_sub_field("side_link_text") ?? "";
                            $secondaryImgLink = get_sub_field("secondary_image_link") ?? "";
                            if ($side == "left") {
                                $smallSideClass = "order-lg-1";
                                $largeSideClass = "order-lg-2";
                            } else if ($side == "right") {
                                $smallSideClass = "order-lg-2";
                                $largeSideClass = "order-lg-1";
                            }

                            ?>
                            <div class="banner-slide-side swiper-slide">
                                <div class="container-fluid">
                                    <div class="row">
                                        <div class="col-lg-4 col-xxl-3 order-2 small-side <?= $smallSideClass ?>">
                                            <?= $sideTitle !== "" ? "<h3 class='accent'>".$sideTitle."</h3>" : "" ; ?> 
                                            <?= $sideText !== "" ? "<p>".$sideText."</p>" : "" ; ?> 
                                            <?= $sideLinkText !== "" ? "<a href='".$sideLink."'><span class='cac-btn-graphic--alt btn-graphic--alt accent'>".$sideLinkText."</span></a>" : "" ; ?>
                                            <?php if($secondaryImgLink) {?>
                                                <a class="left--link" href="<?=$secondaryImgLink;?>">
                                            <?php
                                                }
                                            ?>
                                            <?= $sideSecondaryImage !== "" ? "<img class='". $side."' src='".$sideSecondaryImage."'/>" : "" ; ?> 
                                             <?php if($secondaryImgLink){?>
                                                </a>
                                            <?php
                                                }
                                            ?>
                                        </div>
                                        <div class="col-lg-8 col-xxl-9 order-1 large-side <?= $largeSideClass ?>">
                                            <?php if($sideLink){?>
                                                <a href="<?=$sideLink;?>">
                                            <?php
                                                }
                                            ?>
                                            <?= $sidePrimaryImage !== "" ? "<img class='banner-height-el' src='".$sidePrimaryImage."'/>" : "" ; ?> 
                                            <?php if($sideLink){?>
                                                </a>
                                            <?php
                                                }
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php

                        } else if ($type == "centre") {

                            $centreBackgroundImage = get_sub_field("centre_background_image") ?? "";
                            $centreTitle = get_sub_field("centre_title") ?? "";
                            $centerText = get_sub_field("center_text") ?? "";
                            $centreLink = get_sub_field("centre_link") ?? "";
                            $centreLinkText = get_sub_field("centre_link_text") ?? "";

                            

                            ?>
                            <div class="banner-slide-center swiper-slide">
                                <div class="container-fluid" style="background-image: url('<?= $centreBackgroundImage ?>')">
                                    <div class="row">
                                        <div class="container banner-height-el banner-height-el--centered">
                                            <div class="row">
                                            <?= $centreTitle !== "" ? "<h3 class='col-12 accent'>".$centreTitle."</h3>" : "" ; ?> 
                                            <?= $centerText !== "" ? "<p class='col-12'>".$centerText."</p>" : "" ; ?> 
                                            <?= $centreLinkText !== "" ? "<a class='col-12' href='".$centreLink."'><span class='cac-btn-graphic--alt btn-graphic--alt accent'>".$centreLinkText."</span></a>" : "" ; ?>
                                                
                                                <?php
                                                if( have_rows('center_logos') ) {
                                                    ?>
                                                    <div class="banner-slide-logos col-12">
                                                    <?php
                                                        while ( have_rows('center_logos') ) { 
                                                            the_row();
                                                            $logo = get_sub_field("logo") ?? "";
                                                            $link = get_sub_field("link");
                                                            if($link){?>
                                                                <a class="col center-logo-link" href="<?=$sideLink;?>">
                                                            <?php
                                                                }else{
                                                                    ?>
                                                                    <div class="col">
                                                                <?php
                                                                }
                                                            ?>
                                                                <img src="<?= $logo ?>"/>
                                                                <?php
                                                                    if($link){?>
                                                                </a>
                                                                
                                                            <?php
                                                                }else{
                                                                    ?>
                                                                    </div>
                                                                    <?php
                                                                }
                                                        }
                                                    ?>
                                                    </div>
                                                    <?php
                                                }
                                                ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php

                        }
                    }
                    ?>
                </div>
            </div>
        <?php
        }
        ?>
        </div>
        <div class="banner-slider-buttons">
            <div class="swiper-button-next swiper-button-next--banner"></div>
            <div class="swiper-button-prev swiper-button-prev--banner"></div>
        </div>
    </div>
</div>

==> blue2-theme-simon-howie-dev-theme-2.0.27-00a692.tar: templates/sections/flex-banner-slider.php <==
<?php

$title = get_sub_field("title") ?? "";

?>
<div class="section section--banner-slider">
    <div class="container">
        <?= $title !== "" ? "<h2 class='accent'>".$title."</h2>" : "" ; ?> 
        <div class="row">
        <?php
        if (have_rows('slides')) {
            $i = 0;
            ?>
            <div class="swiper-pagination"></div>
            <div class="swiper-container banner-slider-swiper">
                <div class="swiper-wrapper" style="">   
                    <?php
                    while (have_rows('slides')) { 
                        the_row();

                        $type = get_sub_field("type") ?? "";
                        $i++;
                        if ($type == "side") {

                            $side = get_sub_field("side") ?? "";
                            $sideTitle = get_sub_field("side_title") ?? "";
                            $sideText = get_sub_field("side_text") ?? "";
                            $sidePrimaryImage = get_sub_field("side_primary_image") ?? "";
                            $sideSecondaryImage = get_sub_field("side_secondary_image") ?? "";
                            $sideLink = get_sub_field("side_link") ?? "";
                            $sideLinkText = get_sub_field("side_link_text") ?? "";
                            $secondaryImgLink = get_sub_field("secondary_image_link") ?? "";
                            if ($side == "left") {
                                $smallSideClass = "order-lg-1";
                                $largeSideClass = "order-lg-2";
                            } else if ($side == "right") {
                                $smallSideClass = "order-lg-2";
                                $largeSideClass = "order-lg-1";
                            }

                            ?>
                            <div class="banner-slide-side swiper-slide slide-no--<?=$i;?>">
                                <div class="container-fluid">
                                    <div class="row">
                                        <div class="col-lg-4 col-xxl-3 order-2 small-side <?= $smallSideClass ?>">
                                            <?= $sideTitle !== "" ? "<h3 class='accent'>".$sideTitle."</h3>" : "" ; ?> 
                                            <?= $sideText !== "" ? "<p>".$sideText."</p>" : "" ; ?> 
                                            <?= $sideLinkText !== "" ? "<a href='".$sideLink."'><span class='cac-btn-graphic--alt btn-graphic--alt accent'>".$sideLinkText."</span></a>" : "" ; ?>
                                            <?php if($secondaryImgLink) {?>
                                                <a class="left--link" href="<?=$secondaryImgLink;?>">
                                            <?php
                                                }
                                            ?>
                                            <?= $sideSecondaryImage !== "" ? "<img class='". $side."' src='".$sideSecondaryImage."'/>" : "" ; ?> 
                                             <?php if($secondaryImgLink){?>
                                                </a>
                                            <?php
                                                }
                                            ?>
                                        </div>
                                        <div class="col-lg-8 col-xxl-9 order-1 large-side <?= $largeSideClass ?>">
                                            <?php if($sideLink){?>
                                                <a href="<?=$sideLink;?>">
                                            <?php
                                                }
                                            ?>
                                            <?= $sidePrimaryImage !== "" ? "<img class='banner-height-el' src='".$sidePrimaryImage."'/>" : "" ; ?> 
                                            <?php if($sideLink){?>
                                                </a>
                                            <?php
                                                }
                                            ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php

                        } else if ($type == "centre") {

                            $centreBackgroundImage = get_sub_field("centre_background_image") ?? "";
                            $centreTitle = get_sub_field("centre_title") ?? "";
                            $centerText = get_sub_field("center_text") ?? "";
                            $centreLink = get_sub_field("centre_link") ?? "";
                            $centreLinkText = get_sub_field("centre_link_text") ?? "";

                            

                            ?>
                            <div class="banner-slide-center swiper-slide">
                                <div class="container-fluid" style="background-image: url('<?= $centreBackgroundImage ?>')">
                                    <div class="row">
                                        <div class="container banner-height-el banner-height-el--centered">
                                            <div class="row">
                                            <?= $centreTitle !== "" ? "<h3 class='col-12 accent'>".$centreTitle."</h3>" : "" ; ?> 
                                            <?= $centerText !== "" ? "<p class='col-12'>".$centerText."</p>" : "" ; ?> 
                                            <?= $centreLinkText !== "" ? "<a class='col-12' href='".$centreLink."'><span class='cac-btn-graphic--alt btn-graphic--alt accent'>".$centreLinkText."</span></a>" : "" ; ?>
                                                
                                                <?php
                                                if( have_rows('center_logos') ) {
                                                    ?>
                                                    <div class="banner-slide-logos col-12">
                                                    <?php
                                                        while ( have_rows('center_logos') ) { 
                                                            the_row();
                                                            $logo = get_sub_field("logo") ?? "";
                                                            $link = get_sub_field("link");
                                                            if($link){?>
                                                                <a class="col center-logo-link" href="<?=$sideLink;?>">
                                                            <?php
                                                                }else{
                                                                    ?>
                                                                    <div class="col">
                                                                <?php
                                                                }
                                                            ?>
                                                                <img src="<?= $logo ?>"/>
                                                                <?php
                                                                    if($link){?>
                                                                </a>
                                                                
                                                            <?php
                                                                }else{
                                                                    ?>
                                                                    </div>
                                                                    <?php
                                                                }
                                                        }
                                                    ?>
                                                    </div>
                                                    <?php
                                                }
                                                ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php

                        } else if ($type == "product") {

                            $productImage = get_sub_field("product_image") ?? "";
                            $productPackagingImage = get_sub_field("product_packaging_image") ?? "";
                            $productCta1Text = get_sub_field("product_cta_1_text") ?? "";
                            $productCta1Link = get_sub_field("product_cta_1_link") ?? "";
                            $productCta2Text = get_sub_field("product_cta_2_text") ?? "";
                            $productCta2Link = get_sub_field("product_cta_2_link") ?? "";
                            $centerText = get_sub_field("center_text") ?? "";
                            $centreLink = get_sub_field("centre_link") ?? "";
                            $productAwards = get_sub_field("product_awards") ?? "";

                            ?>
                            <div class="banner-slide-product swiper-slide">
                                <div class="container-fluid" style="background-image: url('<?= $productImage ?>')">
                                    <div class="row">
                                                
                                        <?php
                                        if( $productPackagingImage !== "" ) {
                                            ?>
                                            <div class="col-12 col-lg-4 product-slide-item">
                                                <img src="<?=$productPackagingImage?>"></img>
                                            </div>
                                            <?php
                                        }

                                        if( $productCta1Link !== "" && $productCta1Text !== "" ) {
                                            ?>
                                            <div class="col-12 col-lg-2 product-slide-item">
                                                <a href="<?=$productCta1Link?>"><?= $productCta1Text ?></a>
                                            </div>
                                            <?php
                                        }
                                        if( $productCta2Link !== "" && $productCta2Text !== "" ) {
                                            ?>
                                            <div class="col-12 col-lg-2 product-slide-item">
                                                <a href="<?=$productCta2Link?>"><?= $productCta2Text ?></a>
                                            </div>
                                            <?php
                                        }
                                        
                                        if( have_rows('product_awards') ) {
                                            while ( have_rows('product_awards') ) { 
                                                the_row();
                                                $icon = get_sub_field("icon") ?? "";
                                                if($icon){
                                                ?>
                                                    <div class="col-12 col-lg-2 product-slide-item">
                                                        <img src="<?= $icon ?>"/>
                                                    </div>
                                                <?php
                                                }
                                            }
                                        }
                                        ?>
                                    </div>
                                </div>
                            </div>
                            <?php
                        }
                    }
                    ?>
                </div>
            </div>
        <?php
        }
        ?>
        </div>
        <div class="banner-slider-buttons">
            <div class="swiper-button-next swiper-button-next--banner"></div>
            <div class="swiper-button-prev swiper-button-prev--banner"></div>
        </div>
        <?php
            if( have_rows('call_to_action_buttons') ){
            ?>
            <div class="flex-fill align-self-center text-center banner-slider__cta-row">
                <?php
                while( have_rows('call_to_action_buttons') ){ 
                    the_row();
                    $cta = get_sub_field('call_to_action');
                    ?>
                    <a class="btn btn-graphic" href="<?=$cta['url'];?>" target="<?=$cta['target'];?>"><?= $cta['title']; ?></a>
                    <?php
                }
            ?>
            </div>
            <?php
            }
		?>
    </div>
</div>
